@@ -37,9 +37,9 @@
 
 /* Useful in particular for loadshared where the full path
  * to the lib is needed */
-#define GDCM_SOURCE_DIR "/opt/local/var/macports/build/gdcmKXUuZ1/work/GDCM-3.0.26"
-#define GDCM_EXECUTABLE_OUTPUT_PATH "/opt/local/var/macports/build/gdcmKXUuZ1/work/build/bin"
-#define GDCM_LIBRARY_OUTPUT_PATH    "/opt/local/var/macports/build/gdcmKXUuZ1/work/build/bin"
+#define GDCM_SOURCE_DIR "/opt/local/var/macports/build/gdcm-2c00f3d8/work/GDCM-3.2.2"
+#define GDCM_EXECUTABLE_OUTPUT_PATH "/opt/local/var/macports/build/gdcm-2c00f3d8/work/build/bin"
+#define GDCM_LIBRARY_OUTPUT_PATH    "/opt/local/var/macports/build/gdcm-2c00f3d8/work/build/bin"
 
 /* #undef GDCM_BUILD_TESTING */
 
@@ -82,8 +82,8 @@
 /* #undef GDCM_DEBUG */
 
 #define GDCM_CMAKE_INSTALL_PREFIX "/opt/local"
-#define GDCM_INSTALL_INCLUDE_DIR "include/gdcm-3.0"
-#define GDCM_INSTALL_DATA_DIR "share/gdcm-3.0"
+#define GDCM_INSTALL_INCLUDE_DIR "include/gdcm-3.2"
+#define GDCM_INSTALL_DATA_DIR "share/gdcm-3.2"
 
 /* Whether we are building shared libraries.  */
 #define GDCM_BUILD_SHARED_LIBS
@@ -141,10 +141,10 @@
 
 /* Version number.  */
 #define GDCM_MAJOR_VERSION 3
-#define GDCM_MINOR_VERSION 0
-#define GDCM_BUILD_VERSION 26
-#define GDCM_VERSION "3.0.26"
-#define GDCM_API_VERSION "3.0"
+#define GDCM_MINOR_VERSION 2
+#define GDCM_BUILD_VERSION 2
+#define GDCM_VERSION "3.2.2"
+#define GDCM_API_VERSION "3.2"
 
 /*
 #define GDCM_FILE_META_INFORMATION_VERSION "\0\1"
